PTYProcess

Struct PTYProcess 

pub struct PTYProcess { /* private fields */ }
This struct handles the I/O operations to the standard streams, as well the lifetime of a process running inside a PTY.

Implementations

Source

impl PTYProcess

pub fn new( conin: LocalHandle, conout: LocalHandle, using_pipes: bool, async_: bool, cleanup_tx: Option<Sender<bool>>, ) -> PTYProcess

Create a new PTYProcess instance.

Arguments
  • conin - Handle to the process standard input stream
  • conout - Handle to the process standard output stream
  • using_pipes - true if the streams are Windows named pipes, false if they are files.
  • async_ - true if the streams are async, false if they are sync.
Returns
pub fn read(&self, blocking: bool) -> Result<OsString, OsString>

Read from the process standard output.

Arguments
  • blocking - If true, wait for data to be available. If false, return immediately if no data is available.
Returns
  • Ok(OsString) - The data read from the process output
  • Err(OsString) - If EOF is reached or an error occurs
Notes
  • The actual read operation happens in a background thread with a fixed buffer size
  • The returned data is represented using a OsString since Windows operates over u16 strings
pub fn write(&self, buf: OsString) -> Result<u32, OsString>

Write an (possibly) UTF-16 string into the standard input of a process.

Arguments
  • buf - OsString containing the string to write.
Returns

The total number of characters written if the call was successful, else an OsString containing an human-readable error.

pub fn is_eof(&self) -> Result<bool, OsString>

Check if a process reached End-of-File (EOF).

Returns

true if the process reached EOL, false otherwise. If an error occurs, then a OsString containing a human-readable error is raised.

pub fn get_exitstatus(&self) -> Result<Option<u32>, OsString>

Retrieve the exit status of the process

Returns

None if the process has not exited, else the exit code of the process.

pub fn is_alive(&self) -> Result<bool, OsString>

Determine if the process is still alive.

pub fn set_process(&mut self, process: HANDLE, close_process: bool)

Set the running process behind the PTY.

pub fn get_pid(&self) -> u32

Retrieve the Process ID associated to the current process.

pub fn get_fd(&self) -> isize

Retrieve the process handle ID of the spawned program.

pub fn wait_for_exit(&self) -> Result<bool, OsString>

Wait for the process to exit

pub fn cancel_io(&self) -> Result<bool, OsString>

Cancel all pending I/O operations